# Issues
Please, only use the issue tracker for **problems, bugs and feature requests**.

For help with implementing this slider, ask your question on [stackoverflow](https://stackoverflow.com/questions/tagged/nouislider). I look at questions posted there daily, and you will get you an answer much faster. Please follow the guidelines of the platform.

While I'm happy to help if you can't figure something out, please note this: I won't debug screenshots or issues that do not include **an example with code** that reproduces it. I also won't dig through your production site or huge chunks of unrelated code. I also won't implement your business requirements for you.

# Pull requests
- Detail (in the pull request comment) what your changes do.
- When applicable, include new unit tests. I **won't** merge any untested changes.
- If you are introducing a new feature, update the **documentation**. I'd be happy to do this if you provide the required info.
- **Do NOT** commit `/distribute/*` files, I'll do that upon release.
